Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(337)

Unified Diff: cc/animation/animation_host.h

Issue 2554773002: CC Animation: Rename Active Players to Ticking Players. (Closed)
Patch Set: Rename the argument. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | cc/animation/animation_host.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/animation/animation_host.h
diff --git a/cc/animation/animation_host.h b/cc/animation/animation_host.h
index e91b55e0f09757da8b91cdb5a339cd4307cb357c..f1ee29449fb3f902b4763cd7ca64c2b58c9fc31a 100644
--- a/cc/animation/animation_host.h
+++ b/cc/animation/animation_host.h
@@ -95,10 +95,10 @@ class CC_ANIMATION_EXPORT AnimationHost
void PushPropertiesTo(MutatorHost* host_impl) override;
void SetSupportsScrollAnimations(bool supports_scroll_animations) override;
- bool NeedsAnimateLayers() const override;
+ bool NeedsTickAnimations() const override;
bool ActivateAnimations() override;
- bool AnimateLayers(base::TimeTicks monotonic_time) override;
+ bool TickAnimations(base::TimeTicks monotonic_time) override;
bool UpdateAnimationState(bool start_ready_animations,
MutatorEvents* events) override;
@@ -153,7 +153,7 @@ class CC_ANIMATION_EXPORT AnimationHost
float* start_scale) const override;
bool HasAnyAnimation(ElementId element_id) const override;
- bool HasActiveAnimationForTesting(ElementId element_id) const override;
+ bool HasTickingAnimationForTesting(ElementId element_id) const override;
void ImplOnlyScrollAnimationCreate(ElementId element_id,
const gfx::ScrollOffset& target_offset,
@@ -171,16 +171,16 @@ class CC_ANIMATION_EXPORT AnimationHost
// This should only be called from the main thread.
ScrollOffsetAnimations& scroll_offset_animations() const;
- // Registers the given animation player as active. An active animation
- // player is one that has a running animation that needs to be ticked.
- void ActivateAnimationPlayer(scoped_refptr<AnimationPlayer> player);
+ // Registers the given animation player as ticking. A ticking animation
+ // player is one that has a running animation.
+ void AddToTicking(scoped_refptr<AnimationPlayer> player);
// Unregisters the given animation player. When this happens, the
- // animation player will no longer be ticked (since it's not active).
- void DeactivateAnimationPlayer(scoped_refptr<AnimationPlayer> player);
+ // animation player will no longer be ticked.
+ void RemoveFromTicking(scoped_refptr<AnimationPlayer> player);
- const PlayersList& active_players_for_testing() const;
- const ElementToAnimationsMap& all_element_animations_for_testing() const;
+ const PlayersList& ticking_players_for_testing() const;
+ const ElementToAnimationsMap& element_animations_for_testing() const;
private:
explicit AnimationHost(ThreadInstance thread_instance);
@@ -192,7 +192,7 @@ class CC_ANIMATION_EXPORT AnimationHost
void EraseTimeline(scoped_refptr<AnimationTimeline> timeline);
ElementToAnimationsMap element_to_animations_map_;
- PlayersList active_players_;
+ PlayersList ticking_players_;
// A list of all timelines which this host owns.
using IdToTimelineMap =
« no previous file with comments | « no previous file | cc/animation/animation_host.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698